mindroot.coreplugins.index package
==================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   mindroot.coreplugins.index.handlers

Submodules
----------

mindroot.coreplugins.index.mod module
-------------------------------------

.. automodule:: mindroot.coreplugins.index.mod
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.index.models module
----------------------------------------

.. automodule:: mindroot.coreplugins.index.models
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.index.router module
----------------------------------------

.. automodule:: mindroot.coreplugins.index.router
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.index.utils module
---------------------------------------

.. automodule:: mindroot.coreplugins.index.utils
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: mindroot.coreplugins.index
   :members:
   :show-inheritance:
   :undoc-members:
